@@ -1,5 +1,6 @@
 //! rsw watch
 
+use ignore::gitignore::Gitignore;
 use notify::{DebouncedEvent::*, RecursiveMode::*, Watcher};
 use path_clean::PathClean;
 use regex::Regex;
@@ -10,7 +11,7 @@ use std::{
 use crate::config::{CrateConfig, RswConfig};
 use crate::core::{Build, RswErr, RswInfo};
 
-use crate::utils::print;
+use crate::utils::{get_root, print};
 
 pub struct Watch {
     config: Rc<RswConfig>,
@@ -27,6 +28,7 @@ impl Watch {
         let mut crate_map = HashMap::new();
         let mut path_map = HashMap::new();
         let (tx, rx) = channel();
+        let root = format!("{}/", get_root().to_string_lossy().to_string());
 
         let mut watcher = match notify::watcher(tx, Duration::from_secs(1)) {
             Ok(w) => w,
@@ -52,6 +54,8 @@ impl Watch {
 
         print(RswInfo::SplitLine);
 
+        let (gitignore, _) = Gitignore::new("./.watchignore");
+
         loop {
             let first_event = rx.recv().unwrap();
             sleep(Duration::from_millis(config.interval.unwrap()));
@@ -64,6 +68,15 @@ impl Watch {
                 match event {
                     Write(path) | Remove(path) | Rename(_, path) => {
                         let path = Rc::new(path);
+
+                        let path2 = path.to_string_lossy().to_string();
+                        let project_path_split = path2.split(&root);
+                        let project_path = project_path_split.collect::<Vec<&str>>().join("");
+
+                        if gitignore.matched(project_path, false).is_ignore() {
+                            continue;
+                        }
+
                         for (key, val) in &path_map {
                             if Regex::new(val.to_str().unwrap())
                                 .unwrap()
